@@ -12,7 +12,7 @@ Python.
 
 from __future__ import division
 
-__version__ = "1.0.0"
+__version__ = "1.1.0"
 version_info = tuple([int(num) for num in __version__.split('.')])
 
 __all__ = [
@@ -77,7 +77,14 @@ if sys.platform.startswith("linux"):
                                  IOPRIO_CLASS_NONE,
                                  IOPRIO_CLASS_RT,
                                  IOPRIO_CLASS_BE,
-                                 IOPRIO_CLASS_IDLE)
+                                 IOPRIO_CLASS_IDLE,
+                                 RLIM_INFINITY,
+                                 RLIMIT_AS, RLIMIT_CORE, RLIMIT_CPU,
+                                 RLIMIT_DATA, RLIMIT_FSIZE, RLIMIT_LOCKS,
+                                 RLIMIT_MEMLOCK, RLIMIT_MSGQUEUE, RLIMIT_NICE,
+                                 RLIMIT_NOFILE, RLIMIT_NPROC, RLIMIT_RSS,
+                                 RLIMIT_RTPRIO, RLIMIT_RTTIME,
+                                 RLIMIT_SIGPENDING, RLIMIT_STACK)
     phymem_buffers = _psplatform.phymem_buffers
     cached_phymem = _psplatform.cached_phymem
 
@@ -142,6 +149,7 @@ class Process(object):
          - parent
          - get_children()
          - set_nice()
+         - set_rlimit()
          - suspend()
          - resume()
          - send_signal()
@@ -207,7 +215,7 @@ class Process(object):
         """
         excluded_names = set(['send_signal', 'suspend', 'resume', 'terminate',
                               'kill', 'wait', 'is_running', 'as_dict', 'parent',
-                              'get_children', 'nice'])
+                              'get_children', 'nice', 'get_rlimit'])
         retdict = dict()
         for name in set(attrs or dir(self)):
             if name.startswith('_'):
@@ -287,7 +295,7 @@ class Process(object):
     def name(self):
         """The process name."""
         name = self._platform_impl.get_process_name()
-        if os.name == 'posix':
+        if os.name == 'posix' and len(name) >= 15:
             # On UNIX the name gets truncated to the first 15 characters.
             # If it matches the first part of the cmdline we return that
             # one instead because it's usually more explicative.
@@ -419,7 +427,7 @@ class Process(object):
         whether PID has been reused."""
         return self._platform_impl.set_process_nice(value)
 
-    # available only on Linux and Windows >= Vista
+    # Linux and Windows >= Vista only
     if hasattr(_psplatform.Process, "get_process_ionice"):
 
         def get_ionice(self):
@@ -447,7 +455,39 @@ class Process(object):
             """
             return self._platform_impl.set_process_ionice(ioclass, value)
 
-    # available on Windows and Linux only
+    # Linux only
+    if hasattr(_psplatform.Process, "process_rlimit"):
+
+        def get_rlimit(self, resource):
+            """Get process resource limits as a (soft, hard) tuple.
+
+            'resource' is one of the RLIMIT_* constants.
+
+            See "man prlimit" for further info.
+            """
+            # if pid is 0 prlimit() applies to the calling process and
+            # we don't want that
+            if self.pid == 0:
+                raise ValueError("can't use this method for PID 0 process")
+            return self._platform_impl.process_rlimit(resource)
+
+        @_assert_pid_not_reused
+        def set_rlimit(self, resource, limits):
+            """Set process resource limits pre-emptively checking
+            whether PID has been reused.
+
+            'resource' is one of the RLIMIT_* constants.
+            'limits' is supposed to be a (soft, hard) tuple.
+
+            See "man prlimit" for further info.
+            """
+            # if pid is 0 prlimit() applies to the calling process and
+            # we don't want that
+            if self.pid == 0:
+                raise ValueError("can't use this method for PID 0 process")
+            self._platform_impl.process_rlimit(resource, limits)
+
+    # Windows and Linux only
     if hasattr(_psplatform.Process, "get_process_cpu_affinity"):
 
         def get_cpu_affinity(self):
@@ -518,26 +558,55 @@ class Process(object):
         process Y won't be returned either as the reference to
         process A is lost.
         """
+        if hasattr(_psplatform, 'get_ppid_map'):
+            # Windows only: obtain a {pid:ppid, ...} dict for all running
+            # processes in one shot (faster).
+            ppid_map = _psplatform.get_ppid_map()
+        else:
+            ppid_map = None
+
         ret = []
         if not recursive:
-            for p in process_iter():
-                try:
-                    if p.ppid == self.pid:
-                        # if child happens to be older than its parent
-                        # (self) it means child's PID has been reused
-                        if self.create_time <= p.create_time:
-                            ret.append(p)
-                except NoSuchProcess:
-                    pass
+            if ppid_map is None:
+                # 'slow' version, common to all platforms except Windows
+                for p in process_iter():
+                    try:
+                        if p.ppid == self.pid:
+                            # if child happens to be older than its parent
+                            # (self) it means child's PID has been reused
+                            if self.create_time <= p.create_time:
+                                ret.append(p)
+                    except NoSuchProcess:
+                        pass
+            else:
+                # Windows only (faster)
+                for pid, ppid in ppid_map.items():
+                    if ppid == self.pid:
+                        try:
+                            child = Process(pid)
+                            # if child happens to be older than its parent
+                            # (self) it means child's PID has been reused
+                            if self.create_time <= child.create_time:
+                                ret.append(child)
+                        except NoSuchProcess:
+                            pass
         else:
             # construct a dict where 'values' are all the processes
             # having 'key' as their parent
             table = defaultdict(list)
-            for p in process_iter():
-                try:
-                    table[p.ppid].append(p)
-                except NoSuchProcess:
-                    pass
+            if ppid_map is None:
+                for p in process_iter():
+                    try:
+                        table[p.ppid].append(p)
+                    except NoSuchProcess:
+                        pass
+            else:
+                for pid, ppid in ppid_map.items():
+                    try:
+                        p = Process(pid)
+                        table[ppid].append(p)
+                    except NoSuchProcess:
+                        pass
             # At this point we have a mapping table where table[self.pid]
             # are the current process's children.
             # Below, we look for all descendants recursively, similarly
@@ -1072,6 +1141,7 @@ def cpu_times_percent(interval=0.1, percpu=False):
     global _last_cpu_times_2
     global _last_per_cpu_times_2
     blocking = interval is not None and interval > 0.0
+    WINDOWS = os.name == 'nt'
 
     def calculate(t1, t2):
         global _ptime_cpu_perc_nt
@@ -1083,7 +1153,25 @@ def cpu_times_percent(interval=0.1, percpu=False):
                 field_perc = (100 * field_delta) / all_delta
             except ZeroDivisionError:
                 field_perc = 0.0
-            nums.append(round(field_perc, 1))
+            field_perc = round(field_perc, 1)
+            if WINDOWS:
+                # XXX
+                # Work around:
+                # https://code.google.com/p/psutil/issues/detail?id=392
+                # CPU times are always supposed to increase over time
+                # or at least remain the same and that's because time
+                # cannot go backwards.
+                # Surprisingly sometimes this might not be the case on
+                # Windows where 'system' CPU time can be smaller
+                # compared to the previous call, resulting in corrupted
+                # percentages (< 0 or > 100).
+                # I really don't know what to do about that except
+                # forcing the value to 0 or 100.
+                if field_perc > 100.0:
+                    field_perc = 100.0
+                elif field_perc < 0.0:
+                    field_perc = 0.0
+            nums.append(field_perc)
         if _ptime_cpu_perc_nt is None:
             _ptime_cpu_perc_nt = namedtuple('cpupercent', ' '.join(t1._fields))
         return _ptime_cpu_perc_nt(*nums)
@@ -1335,7 +1423,7 @@ def avail_virtmem():
 
 @_deprecated("psutil.net_io_counters()")
 def network_io_counters(pernic=False):
-    return net_io_counters()
+    return net_io_counters(pernic)
 
 def test():
     """List info of all currently running processes emulating ps aux
