@@ -1,8 +1,6 @@
 #!/usr/bin/env python
-#
-# $Id$
-#
-# Copyright (c) 2009, Jay Loden, Giampaolo Rodola'. All rights reserved.
+
+# Copyright (c) 2009, Giampaolo Rodola'. All rights reserved.
 # Use of this source code is governed by a BSD-style license that can be
 # found in the LICENSE file.
 
@@ -19,13 +17,12 @@ import time
 import socket
 import threading
 import types
+import sys
 
 import psutil
 import psutil._common
 from psutil._compat import PY3, callable, xrange
-from test_psutil import POSIX, LINUX, WINDOWS, OSX, BSD, TESTFN
-from test_psutil import (reap_children, skipUnless, skipIf, supports_ipv6,
-                         safe_remove, get_test_subprocess)
+from test_psutil import *
 
 # disable cache for Process class properties
 psutil._common.cached_property.enabled = False
@@ -95,7 +92,9 @@ class TestProcessObjectLeaks(Base):
         for attr in [x for x in dir(self) if x.startswith('test')]:
             if attr[5:] not in supported_attrs:
                 meth = getattr(self, attr)
-                @skipIf(True)
+                name = meth.__func__.__name__.replace('test_', '')
+                @unittest.skipIf(True,
+                                 "%s not supported on this platform" % name)
                 def test_(self):
                     pass
                 setattr(self, attr, types.MethodType(test_, self))
@@ -149,7 +148,11 @@ class TestProcessObjectLeaks(Base):
         self.execute('get_ionice')
 
     def test_set_ionice(self):
-        self.execute('set_ionice', psutil.IOPRIO_CLASS_NONE)
+        if WINDOWS:
+            value = psutil.Process(os.getpid()).get_ionice()
+            self.execute('set_ionice', value)
+        else:
+            self.execute('set_ionice', psutil.IOPRIO_CLASS_NONE)
 
     def test_username(self):
         self.execute('username')
@@ -181,7 +184,7 @@ class TestProcessObjectLeaks(Base):
     def test_terminal(self):
         self.execute('terminal')
 
-    @skipUnless(WINDOWS)
+    @unittest.skipIf(POSIX, "not worth being tested on POSIX (pure python)")
     def test_resume(self):
         self.execute('resume')
 
@@ -204,12 +207,22 @@ class TestProcessObjectLeaks(Base):
             f.close()
 
     # OSX implementation is unbelievably slow
-    @skipIf(OSX)
+    @unittest.skipIf(OSX, "OSX implementation is too slow")
     def test_get_memory_maps(self):
         self.execute('get_memory_maps')
 
+    @unittest.skipUnless(LINUX, "feature not supported on this platform")
+    def test_get_rlimit(self):
+        self.execute('get_rlimit', psutil.RLIMIT_NOFILE)
+
+
+    @unittest.skipUnless(LINUX, "feature not supported on this platform")
+    def test_get_rlimit(self):
+        limit = psutil.Process(os.getpid()).get_rlimit(psutil.RLIMIT_NOFILE)
+        self.execute('set_rlimit', psutil.RLIMIT_NOFILE, limit)
+
     # Linux implementation is pure python so since it's slow we skip it
-    @skipIf(LINUX)
+    @unittest.skipIf(LINUX, "not worth being tested on Linux (pure python)")
     def test_get_connections(self):
         def create_socket(family, type):
             sock = socket.socket(family, type)
@@ -230,8 +243,14 @@ class TestProcessObjectLeaks(Base):
             s.bind(TESTFN)
             s.listen(1)
             socks.append(s)
+        kind = 'all'
+        # TODO: UNIX sockets are temporarily implemented by parsing
+        # 'pfiles' cmd  output; we don't want that part of the code to
+        # be executed.
+        if SUNOS:
+            kind = 'inet'
         try:
-            self.execute('get_connections', kind='all')
+            self.execute('get_connections', kind=kind)
         finally:
             for s in socks:
                 s.close()
@@ -277,13 +296,16 @@ class TestModuleFunctionsLeaks(Base):
         if callable(obj):
             retvalue = obj(*args, **kwargs)
 
-    @skipIf(POSIX)
+    @unittest.skipIf(POSIX, "not worth being tested on POSIX (pure python)")
     def test_pid_exists(self):
         self.execute('pid_exists', os.getpid())
 
     def test_virtual_memory(self):
         self.execute('virtual_memory')
 
+    # TODO: remove this skip when this gets fixed
+    @unittest.skipIf(SUNOS,
+                     "not worth being tested on SUNOS (uses a subprocess)")
     def test_swap_memory(self):
         self.execute('swap_memory')
 
@@ -293,21 +315,22 @@ class TestModuleFunctionsLeaks(Base):
     def test_per_cpu_times(self):
         self.execute('cpu_times', percpu=True)
 
-    @skipUnless(WINDOWS)
+    @unittest.skipIf(POSIX, "not worth being tested on POSIX (pure python)")
     def test_disk_usage(self):
         self.execute('disk_usage', '.')
 
     def test_disk_partitions(self):
         self.execute('disk_partitions')
 
-    def test_network_io_counters(self):
-        self.execute('network_io_counters')
+    def test_net_io_counters(self):
+        self.execute('net_io_counters')
 
     def test_disk_io_counters(self):
         self.execute('disk_io_counters')
 
     # XXX - on Windows this produces a false positive
-    @skipIf(WINDOWS)
+    @unittest.skipIf(WINDOWS,
+                     "XXX produces a false positive on Windows")
     def test_get_users(self):
         self.execute('get_users')
 
@@ -319,7 +342,9 @@ def test_main():
              TestModuleFunctionsLeaks,]
     for test in tests:
         test_suite.addTest(unittest.makeSuite(test))
-    unittest.TextTestRunner(verbosity=2).run(test_suite)
+    result = unittest.TextTestRunner(verbosity=2).run(test_suite)
+    return result.wasSuccessful()
 
 if __name__ == '__main__':
-    test_main()
+    if not test_main():
+        sys.exit(1)
